.. include:: /_includes/wip_prolog.rst

:mod:`stix.exploit_target.configuration` Module
===============================================

.. module:: stix.exploit_target.configuration

Classes
-------

.. autoclass:: Configuration
	:show-inheritance:
	:members:
